==> wikitty-api-2.0-sources.jar: org/nuiton/wikitty/search/Not.java <==
package org.nuiton.wikitty.search;

import java.io.Serializable;

/**
 * Not operator is used to build negative restriction for request on content.
 * <br>
 * <br>
 * For example, use: RestrictionHelper.not( RestrictionHelper.eq( myElement ,
 * "myValue" ) )
 */
public class Not extends Restriction implements Serializable {

    // serialVersionUID is used for serialization.
    private static final long serialVersionUID = 1L;

    protected Restriction restriction;

    /**
     * Default constructor
     */
    public Not() {
        super();
    }

    /**
     * Constructor with all parameters initialized
     * 
     * @param restriction
     */
    public Not(Restriction restriction) {
        this.restriction = restriction;
    }

    /**
     * Return restriction
     * 
     * @return
     */
    public Restriction getRestriction() {
        return restriction;
    }

    /**
     * Set a value to parameter restriction.
     * 
     * @param restriction
     */
    public void setRestriction(Restriction restriction) {
        this.restriction = restriction;
    }

    /**
     * Equality test based attributes values
     * 
     * @param other Value to compare
     */
    public boolean equals(Object other) {
        if (this == other) {
            return true;
        }
        if (!(other instanceof Not)) {
            return false;
        }

        final Not not = (Not) other;

        if ((restriction == null && not.getRestriction() != null)
                || (restriction != null && !restriction.equals(not
                        .getRestriction()))) {
            return false;
        }

        return true;
    }

    public int hashCode() {
        int result = Not.class.getName().hashCode();
        if (restriction != null) {
            result = 29 * result + restriction.hashCode();
        }
        return result;
    }

}

==> wikitty-api-2.2.1-sources.jar: org/nuiton/wikitty/search/Not.java <==
package org.nuiton.wikitty.search;

import java.io.Serializable;

/**
 * Not operator is used to build negative restriction for request on content.
 * <br>
 * <br>
 * For example, use: RestrictionHelper.not( RestrictionHelper.eq( myElement ,
 * "myValue" ) )
 */
public class Not extends Restriction implements Serializable {

    // serialVersionUID is used for serialization.
    private static final long serialVersionUID = 1L;

    protected Restriction restriction;

    /**
     * Default constructor
     */
    public Not() {
        super();
    }

    /**
     * Constructor with all parameters initialized
     * 
     * @param restriction
     */
    public Not(Restriction restriction) {
        this.restriction = restriction;
    }

    /**
     * Return restriction
     * 
     * @return
     */
    public Restriction getRestriction() {
        return restriction;
    }

    /**
     * Set a value to parameter restriction.
     * 
     * @param restriction
     */
    public void setRestriction(Restriction restriction) {
        this.restriction = restriction;
    }

    /**
     * Equality test based attributes values
     * 
     * @param other Value to compare
     */
    public boolean equals(Object other) {
        if (this == other) {
            return true;
        }
        if (!(other instanceof Not)) {
            return false;
        }

        final Not not = (Not) other;

        if ((restriction == null && not.getRestriction() != null)
                || (restriction != null && !restriction.equals(not
                        .getRestriction()))) {
            return false;
        }

        return true;
    }

    public int hashCode() {
        // equals use objects that are not constant through time
        // then, unable to create hashCode from those objects 
        // returning a constant hash-code
        return Not.class.hashCode();
    }

}
